@@ -37,10 +37,8 @@ _SUPPORTED_USERS['aodh']='aodh 42402 42402 /var/lib/aodh kolla'
 _SUPPORTED_USERS['barbican']='barbican 42403 42403 /var/lib/barbican kolla,nfast'
 _SUPPORTED_USERS['ceilometer']='ceilometer 42405 42405 /var/lib/ceilometer kolla'
 _SUPPORTED_USERS['cinder']='cinder 42407 42407 /var/lib/cinder kolla'
-_SUPPORTED_USERS['cloud-admin']='cloud-admin 42401 42401 /home/cloud-admin'
 _SUPPORTED_USERS['collectd']='collectd 42409 42409 /var/lib/collectd kolla'
 _SUPPORTED_USERS['designate']='designate 42411 42411 /var/lib/designate kolla'
-_SUPPORTED_USERS['ec2api']='ec2api 42466 42466 /var/lib/ec2api kolla'
 _SUPPORTED_USERS['etcd']='etcd 42413 42413 /var/lib/etcd kolla'
 _SUPPORTED_USERS['glance']='glance 42415 42415 /var/lib/glance kolla'
 _SUPPORTED_USERS['gnocchi']='gnocchi 42416 42416 /var/lib/gnocchi kolla'
@@ -63,10 +61,9 @@ _SUPPORTED_USERS['nova']='nova 42436 42436 /var/lib/nova qemu,libvirt,kolla'
 _SUPPORTED_USERS['novajoin']='novajoin 42470 42470 /var/lib/novajoin kolla'
 _SUPPORTED_USERS['octavia']='octavia 42437 42437 /var/lib/octavia kolla'
 _SUPPORTED_USERS['openvswitch']='openvswitch 42476 42476'
-_SUPPORTED_USERS['panko']='panko 42438 42438 /var/lib/panko ceilometer,kolla'
 _SUPPORTED_USERS['placement']='placement 42482 42482 /var/lib/placement kolla'
 _SUPPORTED_USERS['qdrouterd']='qdrouterd 42465 42465 /var/lib/qdrouterd kolla'
-_SUPPORTED_USERS['qemu']='qemu 107 107'
+_SUPPORTED_USERS['qemu']='qemu 42427 42427'
 _SUPPORTED_USERS['rabbitmq']='rabbitmq 42439 42439 /var/lib/rabbitmq kolla'
 _SUPPORTED_USERS['redis']='redis 42460 42460 /run/redis kolla'
 _SUPPORTED_USERS['swift']='swift 42445 42445 /var/lib/swift kolla'
