@@ -110,12 +110,12 @@ class TestBuildahBuilder(base.TestCase):
         dest = '127.0.0.1:8787/master/fedora-binary-fedora-base:latest'
         container_build_path = WORK_DIR + '/' + 'fedora-base'
         logfile = '/tmp/kolla/fedora-base/fedora-base-build.log'
-        buildah_cmd_build = ['bud', '--format', 'docker',
-                             '--tls-verify=False', '--layers',
-                             '--logfile', logfile, '-t',
-                             dest, container_build_path]
+        buildah_cmd_build = ['--log-level debug', 'bud', '--format', 'docker',
+                             '--tls-verify=False', '--layers', '--logfile',
+                             logfile, '-t', dest, container_build_path]
         args.extend(buildah_cmd_build)
-        bb(WORK_DIR, DEPS).build('fedora-base', container_build_path)
+        bb(WORK_DIR, DEPS, debug=True).build('fedora-base',
+                                             container_build_path)
         mock_process.assert_called_once_with(
             *args,
             check_exit_code=True,
